function initPlayer(id, isDebug) {
    // if we are indeed in debug mode, set it to to this global var;
    window.isDebug = isDebug;

    var cookieVolume = 'lastSetVolume';
    var cookieMuteState = 'wasMuted';
    var playerElem = $("#"+id);
    var mediaUrl = getUrlParameter('url') || ''; // default to empty string so that we dont produce errors when deleting a torrent that has a file playing. Looks as if MEJS still tries to play in this scenario.
    var isAudio = (parseInt(getUrlParameter("audio")) == 1);
    var hideCursorTimer;

    if (isDebug) {
        if (!mediaUrl) {
            mediaUrl = "https://archive.org/download/Windows7WildlifeSampleVideo/Wildlife_512kb.mp4";
            /* XXX test files for development. football.ts will show the error page
              mediaUrl = 'http://www.tonycuffe.com/mp3/girlwho.mp3';
              mediaUrl = 'http://random.net.ua/video_test/Woman-with-news.webm';
              mediaUrl = 'http://www.dododge.net/roku/hd-test-streams/football.ts';
              */
        }
    }
    
    playerElem.prop("src", mediaUrl);

    // we need to grab from src property as getting the URL parameter only works while streaming. This allows us to grab the fileName even when the file has finished downloading
    var fileName = playerElem.prop("src");
    fileName = prettifyString(fileName);
    
    //For making the custom fullscreen button
    var $fsButton = $('<div class="mejs-button mejs-fullscreen-button"><button></button></div>');
    MediaElementPlayer.prototype.buildcustomfullscreen = function(player, controls, layers, media) {
        $fsButton.appendTo(controls);
        $fsButton.click(function() {
                logger.debug('Our custom fullscreen button was clicked');

                /*
                 * As we hide the curosr in fullscreen mode, we clear any potential timers whose callback
                 *  would execute after we leave fullscreen. 
                 * Remove cursor CSS properties too as a safety measure.
                 */
                clearTimeout(hideCursorTimer);
                $('.mejs-mediaelement, .mejs-controls').css('cursor', '');

                isFullScreen = $fsButton.hasClass("mejs-unfullscreen");
                if (isFullScreen) {
                    $fsButton.removeClass("mejs-unfullscreen");
                    window.external.playback_cancelFullScreen();
                }
                else {
                    $fsButton.addClass("mejs-unfullscreen");
                    window.external.playback_goFullScreen();
                }
            });     
    };
    
    MediaElementPlayer.prototype.buildcustomstop = function(player, controls, layers, media) {
        var t = this;
        var stopButton = $('<div class="mejs-button mejs-stop-button mejs-stop"><button type="button" aria-controls="' + t.id + '" title="Stop" aria-label="Stop"></button></div>');
        stopButton.appendTo(controls);
        stopButton.click(function() {
                player.customPlaying = false;
                
                if (! media.paused) {
                    media.pause();
                }
                if (media.currentTime > 0) {
                    media.setCurrentTime(0);
                    media.pause();
                    controls.find('.mejs-time-current').width('0px');
                    controls.find('.mejs-time-handle').css('left', '0px');
                    controls.find('.mejs-time-float-current').html( mejs.Utility.secondsToTimeCode(0) );
                    controls.find('.mejs-currenttime').html( mejs.Utility.secondsToTimeCode(0) );					
                    layers.find('.mejs-poster').show();
                }

                /* Pressing stop should exit fullscreen then send a playback_stop */
                isFullScreen = $fsButton.hasClass("mejs-unfullscreen");
                if (isFullScreen) {
                    $fsButton.removeClass("mejs-unfullscreen");
                    window.external.playback_cancelFullScreen();
                }
                window.external.playback_stop();
            });
    }


    /*
     * Object argument that gets passed into MediaElementPlayer constructor
     * Upon fileplay back error, customError allows us to define HTML to show in the player area
     *    Also, error allows us to define a function to be called upon error as well.
     */
    var opts = {
        alwaysShowControls: isAudio,
        enableKeyboard: true,
        features: ['playpause','customstop','progress','current','duration','tracks','volume','customfullscreen'],
        keyActions: [
            {
                keys: [27],
                action: function(player, media) {
                    if (typeof player.enterFullScreen != 'undefined') {
                        isFullScreen = $fsButton.hasClass("mejs-unfullscreen");
                        if (isFullScreen) {
                            $fsButton.click();
                        }
                    }
                }
            }			
        ],	
        customError: getCustomErrorHtml(mediaUrl),
        success: function (playerEl, domObject, player) {
            // Auto play our content
            player.play();

            // If playing audio file, display the filename
            if (isAudio) {
                playerEl.addEventListener('loadeddata', function(e) { 
                    $(".mejs-mediaelement video").css("opacity", "0"); // so that there is not a black box in middle that blocks the background image of div we are about to insert
                    $(".mejs-container").prepend('<div class="message"><div class="header">' + fileName + '</div></div>');
                });
            }
            
           /*
            * on volume changed, save the value to a cookie so that when we are creating new instances of,
            *   the player, we return to the same volume 
            *
            *  note: volumechange event fires on player instantiation as well
            */
            playerEl.addEventListener('volumechange', function(e) {
                var vol = player.getVolume().toString();
                logger.debug('Volume: ' + vol);
                
                // only save if it is not due to a mute
                if ( ! $('.mejs-button.mejs-volume-button').hasClass('mejs-unmute') ) {
                    logger.debug('Not on mute, saving volume level to cookie');
                    // Cookies is a global var exposed by cookies.js
                    Cookies.set(cookieVolume, vol, { expires: Infinity }); 
                }
            });
            
            // If it was muted, save the this muted state so we know to return to it upon new player instance 
            $(window).unload(function() {
                var isMuted = $('.mejs-button.mejs-volume-button').hasClass('mejs-unmute') ? '1': '0';
                logger.debug('In unload event. Are we muted?: ' + isMuted);

                Cookies.set(cookieMuteState, isMuted, { expires: Infinity }); 
            });

            /*
             * Handle edge case when:
             * 1. User sets a volume, then puts the player on mute
             * 2. Reinstantiates the player (closing the client, playing another file, etc)
             * 3. User clicks unmute.
             * 4. Volume is returned to what the user previously had it set to in step 1 
             *
             * note: there is also a case where: After completing step 2, the user clicks in the volume slider. Then, he clicks on the mute button. The one() event handler is still fired but it looks like it does not execute until after the volume has been set to 0 from the user's intention of muting. Long story short, this does edge case does not surface. 
             */
            $('.mejs-button.mejs-volume-button button').one('click', function() {
                var savedVolume;

                logger.debug('Speaker button was clicked for first time since player instantiation.');
                if (Cookies.get(cookieMuteState) === '1') {
                    logger.debug('Cookie determined that previous state was muted, so revert to umuted volume value');
                    savedVolume = parseFloat(Cookies.get(cookieVolume), 10) ; // 0 < savedVolume < 1
                    Cookies.set(cookieMuteState, '0');
                    player.setVolume(savedVolume);
                }
            });
            // --- End of edge case handling.

            /* 
             * When in fullsreen mode, disable the mouse after a period of the mouse not moving
             */
            $('.mejs-mediaelement, .mejs-controls').mousemove(function() {

                // Are we in fullscreen?
                if (! $fsButton.hasClass("mejs-unfullscreen")) { return; }

                // In the case where the mouse is continously moving, restart the timer each time.
                clearTimeout(hideCursorTimer);
                $('.mejs-mediaelement, .mejs-controls').css('cursor', '');
                hideCursorTimer = setTimeout(function() {
                   $('.mejs-mediaelement, .mejs-controls').css('cursor', 'none');
                   logger.debug('Mouse has hidden');
                }, 2500); // 2500ms is used to keep in sync with the MEJS controls overlay fadeout.

            });

            playerEl.addEventListener('play', function (e) {
                    //Play start request by the user
                    player.customPlaying = true;
                    window.external.playback_play();
                });

            playerEl.addEventListener('playing', function (e) {
                    //Playing has actually begun or resumed
                    player.customPlaying = true;
                    window.external.playback_playing();
                });

            playerEl.addEventListener('pause', function (e) {
                    //Paused
                    if (! player.customPlaying) return;
                    window.external.playback_pause();
                    playerEl.customPlaying = false;
                });

            playerEl.addEventListener('ended', function (e) {
                    //Playback complete
                    if (! player.customPlaying) return;
                    player.customPlaying = false;
                    window.external.playback_ended();
                });

            playerEl.addEventListener('abort', function (e) {
                    //Aborted load.
                    if (! player.customPlaying) return;
                    player.customPlaying = false;
                    window.external.playback_abort();
                });

            playerEl.addEventListener('error', function (e) {
                    //Cancelled because of load error
                    if (! player.customPlaying) return;
                    player.customPlaying = false;
                    window.external.playback_error();
                });

            playerEl.addEventListener('seeked', function (e) {
                    //User has scrubbed the play
                    if (! player.customPlaying) return;
                    window.external.playback_seeked();
                });

            playerEl.addEventListener('waiting', function (e) {
                    //Buffering.
                    if (! player.customPlaying) return;
                    window.external.playback_waiting();
                });
        },
        error: function (playerEl) {
            //alert("ERR " + playerEl.error);
            $('.mejs-controls').remove(); // Do not want to see controls overlay upon seeing custom error message.
        }
    };

    /*
     * Conditionals for adding properties to MediaElementPlayer options object
     */
    
    var cookieVal = Cookies.get(cookieVolume);
    // cookieVal is a string, so we parse via parseInt to turn into number
    if (Cookies.get(cookieMuteState) === '1') {
        opts.startVolume = 0;
    } else if (cookieVal) {
        opts.startVolume = parseFloat(cookieVal, 10) ;   // 0 > startVolume > 1
    }

    /*
     * End of options object conditionals
     */
    
    var myPlayer = new MediaElementPlayer("#"+id, opts);
    myPlayer.enterFullScreen();
    myPlayer.startControlsTimer(1);
    
    var handleResize = function () {
        myPlayer.hideControls(false);
        myPlayer.setPlayerSize($(window).width(), $(window).height());
        myPlayer.setControlsSize();
        myPlayer.showControls(true);
    }
    
    handleResize();
    $(window).resize(handleResize);

/*
    //We have to do this after enterFullScreen() above, to reset the z-index.
    var days = getUrlParameter("daystoexpire");
    if (days) {
        $("#timeNumber").text(days);
        $("#dayWord").text((days == 1) ? "day" : "days");
        
        var expireday = $("#expireDay");
        expireday.css('z-index', 10000);
        expireday.show();
        
        //Show Trial Expiry and then fade.
        setTimeout(function () {
                expireday.fadeOut(1000, function () {
                        expireday.hide();
                    });
            }, 5000);
    }
*/

    window.client_play = function() { 
        myPlayer.play(); 
    }
    
    window.client_pause = function() { 
        myPlayer.pause(); 
    }
}//---- end of  initPlayer()
        
//For getting a url parameter
function getUrlParameter(sParam) {
    var sPageURL = window.location.search.substring(1);
    var sURLVariables = sPageURL.split('&');
    for (var i = 0; i < sURLVariables.length; i++) {
        var sParameterName = sURLVariables[i].split('=');
        if (sParameterName[0] == sParam) {
            return decodeURIComponent(sParameterName[1]);
        }
    }
}

// Helps us insert a string inside an existing string 
function insertAfterTargetStr(src, targetStr, toInsert) {
    var targetStrEndPos = src.indexOf(targetStr) + targetStr.length;

    return src.slice(0, targetStrEndPos) + toInsert + src.slice(targetStrEndPos);
}

// helper method to give us a presentable filename to present to the user
function prettifyString(input) {
    var toPrettify = input;
    // if we can find a forward slash, grab the substring to the right of the last forward slash. Otherwise, we dont use a substring at all
    toPrettify = toPrettify.indexOf('/') > -1 ? toPrettify.slice(toPrettify.lastIndexOf('/') + 1) : toPrettify;

    // also need to strip any query strings that occur
    toPrettify = toPrettify.indexOf('?') > -1 ? toPrettify.slice(0, toPrettify.indexOf('?')) : toPrettify;
    
    // replace %20 which are uri safe encoding of a space char
    toPrettify = toPrettify.replace(/%20/gi, ' ');

    return toPrettify;
}

function getCustomErrorHtml(mediaUrl) {
    // if there is a query string param, strip it all out
    var fileExt = mediaUrl.substring(mediaUrl.lastIndexOf(".") + 1);
    if (fileExt.indexOf('?') > -1) {
        fileExt = fileExt.slice(0, fileExt.indexOf('?')); // get rid of any query strings appended to end
    }
    
    var brand = getUrlParameter('brand') || 'ut'; // default to ut if brand param not supplied

    var iframeUpsell = '<iframe src="http://utclient.utorrent.com/pro/flow/trial/i18n/en/upgrade3-' + brand + '.html?fileExt=' + fileExt + '"></iframe>';
    var iframeFail = '<iframe src="http://utclient.utorrent.com/pro/flow/trial/i18n/en/fail1-' + brand + '.html?fileExt=' + fileExt + '"></iframe>';

    // If we are in debug mode, then point to staging iframe pages
    if (isDebug) {
        iframeUpsell = insertAfterTargetStr(iframeUpsell, 'utclient', '-staging');
        iframeFail = insertAfterTargetStr(iframeFail, 'utclient', '-staging'); 
    }

    // If the extension is one of these, then show the upsell
    var extUpsell = ['mkv', 'avi', 'ogg', 'oga', 'ogv', 'ogm', 'flac', 'wav'];

    return (extUpsell.indexOf(fileExt) > -1) ? iframeUpsell: iframeFail; 
}

var logger = {
    debug: function(msg) {
        if (isDebug) {
            console.log('[DEBUG]: ', msg);
        }
    },
    error: function(msg) {
        if (isDebug) {
            console.log('[ERROR]: ', msg);
        }
    }
};

$(document).ready(function() {
        //Prevent key presses
        $(window).keypress(function (ev) { ev.preventDefault(); });
        $(window).keydown(function (ev) { ev.preventDefault(); });
        $(window).keyup(function (ev) { ev.preventDefault(); });        
    });
